==> haskell-data-default-instances-containers-0.1.0.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-containers
version:              0.1.0.2
visibility:           public
id:
    data-default-instances-containers-0.1.0.2-3u6XEY1XTByLspJ7o3sDFR

key:
    data-default-instances-containers-0.1.0.2-3u6XEY1XTByLspJ7o3sDFR

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in containers
category:             Data
abi:                  12d0d04e37e1e9098563c4ccfb4ba3db
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-containers
hs-libraries:
    HSdata-default-instances-containers-0.1.0.2-3u6XEY1XTByLspJ7o3sDFR

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-instances-containers-0.1.0.3-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-default-instances-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-containers
version:              0.1.0.3
visibility:           public
id:
    data-default-instances-containers-0.1.0.3-4o1vrLdrHKiIw8vCgZ7ZVY

key:
    data-default-instances-containers-0.1.0.3-4o1vrLdrHKiIw8vCgZ7ZVY

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in containers
description:
    This module defines '\''Default'\'' instances for the types '\''S.Set'\'', '\''M.Map'\'',
    '\''IntMap'\'', '\''IntSet'\'', '\''Seq'\'', and '\''Tree'\''.

category:             Data
abi:                  ee3902bb50fa5b33c0404c2591f57940
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/data-default-instances-containers-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-containers
hs-libraries:
    HSdata-default-instances-containers-0.1.0.3-4o1vrLdrHKiIw8vCgZ7ZVY

depends:
    base-4.17.2.1 containers-0.6.7
    data-default-class-0.1.2.0-J3yYo85AtrC9KKZSpt62Yc

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
